@@ -10,7 +10,7 @@
 #pragma interface "sockset"
 #include "AuditSet.h"
 
-#define TCount		35
+#define TCount		TCP_SERV_TOTAL + 2
 #define MAXCAPLEN	1024
 #define SALen		sizeof(struct sockaddr_in)
 
