@@ -10,12 +10,12 @@
 // cgiscan (c) [CKS & Fdisk], VoidEye scanner,
 // httpver (c) Shok
 
-// currently 176 confirmedly vulnerable CGIs, p00r e-commerce ;x
+// currently 181 confirmedly vulnerable CGIs, p00r e-commerce ;x
 
 const char *www_extensions[] =
 {
 "/_vti_bin/shtml.dll",				// frontpage
-"/_vti_bin/shtml.exe"
+"/_vti_bin/shtml.exe",
 "/_vti_inf.html",
 "/_vti_pvt/administrators.pwd",
 "/_vti_pvt/authors.pwd",
@@ -36,6 +36,11 @@ const char *www_extensions[] =
 "/cfdocs/snippets/fileexists.cfm",
 "/cfdocs/snippets/gettempdirectory.cfm",
 "/cfdocs/snippets/viewexample.cfm",
+"/cgi-bin/search.cgi",				// misc stuff
+"/cgi-bin/bigconf.cgi",
+"/cgi-bin/alibaba.pl",
+"/cgi-bin/tst.bat",
+"/cgi-bin/cachemgr.cgi",
 "EOF"
 };
 
@@ -155,7 +160,7 @@ const char *www_cgibin[] =
 "/cgi-bin/perl",
 "/cgi-bin/perl.exe",
 "/cgi-bin/perlshop.cgi",
-"/cgi-bin/pfdisplay.cgi",
+"/cgi-bin/pfdispaly.cgi",
 "/cgi-bin/phf",
 "/cgi-bin/phf.cgi",
 "/cgi-bin/phf.pp",
