@@ -8,6 +8,8 @@
 #ifndef SERVICES_H
 #define SERVICES_H
 
+#define TCP_SERV_TOTAL	35
+
 #define S_TCPMUX	1
 #define S_ECHO		7
 #define S_NSTAT		15
@@ -40,6 +42,8 @@
 #define S_NLPS		2766
 #define S_IRCD		6667
 #define S_XWIN		6000
+#define S_CISCO1	1999
+#define S_CISCO2	7161
 #define S_PROXY		8080
 #define S_BDTRINOO	27665
 #define SU_NBNAME	137
